@@ -35,6 +35,10 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <linux/kd.h>
+#include <QPlainTextEdit>
+#include <QEventLoop>
+#include <QScrollBar>
+#include <QScreen>
 
 #include "base/thread_util.h"
 #include "service/first_boot_hook_worker.h"
@@ -42,6 +46,7 @@
 #include "service/settings_manager.h"
 #include "service/settings_name.h"
 #include "service/screen_adaptation_manager.h"
+#include "service/log_manager.h"
 #include "third_party/global_shortcut/global_shortcut.h"
 #include "ui/frames/first_boot_loading_frame.h"
 #include "ui/frames/system_info_frame.h"
@@ -55,8 +60,10 @@
 #include "ui/frames/control_platform_frame.h"
 #include "ui/frames/inner/system_info_keyboard_frame.h"
 #include "ui/frames/control_panel_frame.h"
-#include "ui/frames/confirm_quit_frame.h"
+#include "ui/frames/warnning_frame.h"
 #include "ui/widgets/wallpaper_item.h"
+#include "ui/widgets/title_label.h"
+#include "ui/widgets/shadow_widget.h"
 #include "ui/models/package_manager_model.h"
 
 DWIDGET_USE_NAMESPACE
@@ -88,6 +95,11 @@ FirstBootSetupWindow::FirstBootSetupWindow(QWidget *parent)
   initConnections();
 
   setWindowFlags(windowFlags() & ~Qt::WindowCloseButtonHint & ~Qt::WindowMinMaxButtonsHint);
+
+#ifndef QT_DEBUG
+    setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);  // 设置窗口不受窗管管控，本地debug调试的时候不生效
+#endif // QT_DEBUG
+
   DTitlebar* titleBar = titlebar();
   titleBar->installEventFilter(this);
   titlebar()->setMenuVisible(false);
@@ -180,9 +192,22 @@ void FirstBootSetupWindow::exitInstall(bool reboot)
 
 }
 
+void FirstBootSetupWindow::showChildFrame(BaseFrameInterface *childFrameInterface)
+{
+    if (shadow_widget->isVisible()) {
+        return;
+    }
+    shadow_widget->setContent(childFrameInterface);
+    shadow_widget->setAttribute(Qt::WA_ShowModal, true);
+    shadow_widget->raise();
+    shadow_widget->show();
+    shadow_widget->repaint();
+    repaint();
+}
+
 void FirstBootSetupWindow::hideChildFrame() const
 {
-
+    shadow_widget->close();
 }
 
 void FirstBootSetupWindow::setWindowIcon(const QString &path)
@@ -197,6 +222,7 @@ void FirstBootSetupWindow::setWindowIcon(const QString &path)
         QLabel *windowLabel = new QLabel;
         windowLabel->setFixedSize(iconSize, iconSize);
         windowLabel->setPixmap(pixmap);
+        windowLabel->setScaledContents(true);
         windowLabel->setParent(this);
         windowLabel->raise();
         windowLabel->setVisible(true);
@@ -209,17 +235,26 @@ void FirstBootSetupWindow::setWindowIcon(const QString &path)
 
 void FirstBootSetupWindow::onCloseEvent()
 {
-    confirm_quit_frame_->display();
+    showChildFrame(confirm_quit_frame_);
 }
 
 void FirstBootSetupWindow::initConnections() {
     connect(close_button_, &DIconButton::clicked, this, &FirstBootSetupWindow::onCloseEvent);
 
-    connect(confirm_quit_frame_, &ConfirmQuitFrame::quitCancelled, this, [=](){
-               confirm_quit_frame_->close();
+    connect(optimize_failed_frame_, &WarnningFrame::quitEntered, this, [=](){
+        hideChildFrame();
+        qApp->setActiveWindow(this);
+     });
+    connect(optimize_failed_frame_, &WarnningFrame::quitCanceled, this, [=](){
+        hideChildFrame();
+        qApp->setActiveWindow(this);
+     });
+
+    connect(confirm_quit_frame_, &WarnningFrame::quitCanceled, this, [=](){
+               hideChildFrame();
                qApp->setActiveWindow(this);
             });
-    connect(confirm_quit_frame_, &ConfirmQuitFrame::quitConfirmed,
+    connect(confirm_quit_frame_, &WarnningFrame::quitEntered,
             this, &FirstBootSetupWindow::shutdownSystem);
 
     connect(loading_frame_, &FirstBootLoadingFrame::closeButtionChange, this
@@ -244,14 +279,6 @@ void FirstBootSetupWindow::initConnections() {
     connect(language_frame_, &LanguageFrame::coverMainWindowFrameLabelsView, this, [=] (bool cover) {
         updateFrameLabelPreviousState(!cover);
     });
-
-    // 主窗口分辨率适配
-    connect(ScreenAdaptationManager::instance(),
-            &ScreenAdaptationManager::primaryAvailableGetometryChanaged,
-            this, [=](const QRect &rect) {
-        this->setFixedSize(rect.size());
-        this->adjustSize();
-    });
 }
 
 void FirstBootSetupWindow::initUI() {
@@ -315,12 +342,25 @@ void FirstBootSetupWindow::initUI() {
     control_panel_frame_->hide();
 
     //this->setFocusPolicy(Qt::TabFocus);
+    shadow_widget = new ShadowWidget(this);
+    shadow_widget->hide();
 }
 
 void FirstBootSetupWindow::initPages()
 {
-    confirm_quit_frame_ = new ConfirmQuitFrame(this);
+    optimize_failed_frame_ = new WarnningFrame(this);
+    optimize_failed_frame_->useTitle(false);
+    optimize_failed_frame_->useCancelButton(false);
+    optimize_failed_frame_->setFocusPolicy(Qt::NoFocus);
+    optimize_failed_frame_->hide();
+
+    confirm_quit_frame_ = new WarnningFrame(this);
+    confirm_quit_frame_->setFocusPolicy(Qt::NoFocus);
+    confirm_quit_frame_->setEnterButtonStyle("QPushButton{ color:#FF5736; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(230, 230, 230); } \
+                                        QPushButton:hover{ color:#FF5736; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(205, 205, 205); } \
+                                      QPushButton:pressed{ color:#FF5736; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(188, 196, 208); }");
     confirm_quit_frame_->hide();
+
     language_frame_ = new LanguageFrame(this);
     m_keyboardFrame = new SystemInfoKeyboardFrame(this);
     system_info_frame_ = new SystemInfoFrame(this);
@@ -375,10 +415,23 @@ void FirstBootSetupWindow::changeEvent(QEvent *event)
             QStandardItem* item = m_frameLabelsModel->item(i);
             FrameInterface* frame = getFrameInterface(item);
             if (frame) {
-                item->setText(frame->returnFrameName());
-                item->setToolTip(frame->returnFrameName());
+                QImage testimage_1(QString(":/images/NO_inactive%1.svg").arg(i+1));
+                QImage testimage_2(":/images/done_inactive.svg");
+                // 因为没有设置自定义的spacing，所以使用的是item的默认spacing，这里通过dstyleditemdelegate源码得知默认的spacing为DStyle::PM_ContentsSpacing
+                int itemimagewidth = m_frameLabelsView->itemSize().width()
+                        - testimage_1.width() - testimage_2.width()
+                        - m_frameLabelsView->itemMargins().left() - m_frameLabelsView->itemMargins().right()
+                        - (DStyleHelper(qApp->style()).pixelMetric(DStyle::PM_ContentsSpacing) * 2);
+                SetItemTextAndTooltip(item, frame->returnFrameName(), itemimagewidth);
             }
         }
+
+        optimize_failed_frame_->setComment(::QObject::tr("An unknown problem has occurred, which may not affect the system running. Please click \"Skip\" to continue the installation. If you cannot enter the system later, please try to reinstall."));
+        optimize_failed_frame_->setEnterButtonText(::QObject::tr("Skip"));
+        confirm_quit_frame_->setTitle(::QObject::tr("Abort Installation"));
+        confirm_quit_frame_->setComment(::QObject::tr("Relevant operations you made in the installation process will not take effect, abort or continue installation?"));
+        confirm_quit_frame_->setCancelButtonText(::QObject::tr("Continue"));
+        confirm_quit_frame_->setEnterButtonText(::QObject::tr("Abort"));
     }
     else {
         QWidget::changeEvent(event);
@@ -387,6 +440,8 @@ void FirstBootSetupWindow::changeEvent(QEvent *event)
 
 void FirstBootSetupWindow::resizeEvent(QResizeEvent *event)
 {
+    shadow_widget->setFixedSize(event->size());
+
     if (close_button_) {
       qInfo() << "Layout margin:" << layout()->margin();
       close_button_->move(width() - close_button_->width() - 10, 0);
@@ -451,8 +506,14 @@ void FirstBootSetupWindow::constructLabelView()
         item->setIcon(QIcon(pixPathTemplate.arg(i)));
         ++i;
 
-        item->setText(tr(frame->returnFrameName().toLatin1().data()));
-        item->setToolTip(frame->returnFrameName());
+        QImage testimage_1(pixPathTemplate.arg(i));
+        QImage testimage_2(":/images/done_inactive.svg");
+        // 因为没有设置自定义的spacing，所以使用的是item的默认spacing，这里通过dstyleditemdelegate源码得知默认的spacing为DStyle::PM_ContentsSpacing
+        int itemimagewidth = m_frameLabelsView->itemSize().width()
+                - testimage_1.width() - testimage_2.width()
+                - m_frameLabelsView->itemMargins().left() - m_frameLabelsView->itemMargins().right()
+                - (DStyleHelper(qApp->style()).pixelMetric(DStyle::PM_ContentsSpacing) * 2);
+        SetItemTextAndTooltip(item, frame->returnFrameName(), itemimagewidth);
 
         QVariant framePointer = QVariant::fromValue(frame);
         item->setData(framePointer, FramePointerRole);
@@ -494,30 +555,30 @@ void FirstBootSetupWindow::registerShortcut() {
   }
 }
 
+void FirstBootSetupWindow::showFailedLog()
+{
+    loading_frame_->showLogFrame(installer::GetLogFilepath());
+    close_button_->show();
+    showChildFrame(optimize_failed_frame_);
+}
+
 void FirstBootSetupWindow::onHookFinished(bool ok) {
-  if (!ok) {
-    qCritical() << "First boot hook failed!";
-  }
-
-  if (!PackageRemoveModel::instance()->start()) {
-      QString log = PackageRemoveModel::instance()->getErr();
-      qWarning() << log;
-      // 如果卸载包有错误，则重新设置弹窗后显示
-      confirm_quit_frame_->setPackageInfo(log);
-      confirm_quit_frame_->display();
-  }
-
-  if (QFile::exists("/usr/sbin/lightdm")) {
-      qDebug() << SpawnCmd("systemctl", QStringList() << "restart" << "lightdm");
-  }
-  else {
-    if (!changeToTTY(2)) {
-      if (!RebootSystemWithMagicKey()) {
-          RebootSystem();
-      }
-      qDebug() << SpawnCmd("killall", QStringList() << "lightdm");
+    if (!ok) {
+        this->showFailedLog();
+    }
+    else if (QFile::exists("/usr/sbin/lightdm")) {
+        qDebug() << SpawnCmd("systemctl", QStringList() << "restart" << "lightdm");
+    }
+    else if (!changeToTTY(2)) {
+        if (!RebootSystemWithMagicKey()) {
+            RebootSystem();
+        }
+        qDebug() << SpawnCmd("killall", QStringList() << "lightdm");
+    }
+    else {
+        qApp->quit();
+        qDebug() << SpawnCmd("systemctl", QStringList() << "stop" << "lightdm");
     }
-  }
 }
 
 void FirstBootSetupWindow::onLanguageSelected()
@@ -716,12 +777,13 @@ void FirstBootSetupWindow::updateFrameLabelPreviousState(bool allow)
 
 void FirstBootSetupWindow::shutdownSystem()
 {
+    hideChildFrame();
     if (!ShutdownSystem()) {
         qWarning() << "ShutdownSystem() failed!";
     }
 
-    if (!ShutdownSystemWithMagicKey()) {
-        qWarning() << "ShutdownSystemWithMagicKey() failed!";
+    if (!PoweroffSystem()) {
+        qWarning() << "PoweroffSystem() failed!";
     }
 }
 
@@ -766,4 +828,29 @@ void FirstBootSetupWindow::updateFrameLabelState(FrameInterface *frame, FrameLab
     }
 }
 
+void FirstBootSetupWindow::setScreen(QScreen *screen)
+{
+    if (screen == m_screen)
+        return;
+
+    if (m_screen) {
+        disconnect(m_screen, &QScreen::geometryChanged, this, &FirstBootSetupWindow::updateGeometry);
+    }
+
+    if (screen) {
+        connect(screen, &QScreen::geometryChanged, this, &FirstBootSetupWindow::updateGeometry);
+    }
+
+    m_screen = screen;
+
+    if (m_screen)
+        updateGeometry();
+}
+
+void FirstBootSetupWindow::updateGeometry()
+{
+    setGeometry(m_screen->availableGeometry());
+    setFixedSize(m_screen->availableSize());
+}
+
 }  // namespace installer
