@@ -104,10 +104,26 @@ void EditPartitionFrame::setPartition(const Partition::Ptr partition) {
   mount_point_model_ = new MountPointModel(mountList, this);
   mount_point_box_->setModel(mount_point_model_);
 
-  os_label_->setPixmap(QPixmap(GetOsTypeLargeIcon(partition->os)));
+  os_label_->setPixmap(QPixmap(GetPartitionIcon128()));
   name_label_->setText(GetPartitionLabelAndPath(partition));
   usage_label_->setText(GetPartitionUsage(partition));
-  usage_bar_->setValue(GetPartitionUsageValue(partition));
+
+  // 对返回的字符串做解析，根据"/"前后数值对的确定磁盘使用量的进度显示
+  QString usagetext = GetPartitionUsage(partition);
+  if(usagetext.indexOf("M") != -1) {
+      usagetext = usagetext.left(usagetext.indexOf("M"));
+  } else if(usagetext.indexOf("G") != -1) {
+      usagetext = usagetext.left(usagetext.indexOf("G"));
+  } else {
+    usagetext = "0/3";
+  }
+  QStringList usagetextlist = usagetext.split("/");
+  usage_bar_->setRange(0, usagetextlist.at(1).toInt());
+  if(usagetextlist.at(0).toInt() > 0) {
+    usage_bar_->setValue(usagetextlist.at(0).toInt());
+  } else {
+    usage_bar_->setValue(0);
+  }
 
   // Update fs list.
   fs_model_->setShowUnknown(partition->fs == FsType::Unknown);
@@ -255,8 +271,8 @@ void EditPartitionFrame::changeEvent(QEvent* event) {
     fs_label_->setText(::QObject::tr("File system"));
     mount_point_label_->setText(::QObject::tr("Mount point"));
     format_check_box_->setText(::QObject::tr("Format the partition"));
-    cancel_button_->setText(::QObject::tr("Cancel"));
-    ok_button_->setText(::QObject::tr("Confirm"));
+    cancel_button_->setText(::QObject::tr("Cancel", "button"));
+    ok_button_->setText(::QObject::tr("Confirm", "button"));
 
     if (m_close_button) {
         m_close_button->move(width() - m_close_button->width(), 0);
