@@ -60,7 +60,7 @@ const qint64 kMinimumPartitionSize = 100 * kMebiByte;
 const int kButtonwidth = 197;
 
 const int kMainFrameWidth = 560;
-const int kMainFrameHeight = 500;
+const int kMainFrameHeight = 520;
 
 const int kHintLabelWidth = 80;
 const int kHintLabelInputWidgetSpacing = 10;
@@ -219,7 +219,7 @@ bool NewPartitionFrame::focusSwitch()
 bool NewPartitionFrame::doSpace()
 {
     if (type_box_ == m_current_focus_widget) {
-        QModelIndex testindex = fs_box_->view()->selectionModel()->currentIndex();
+        QModelIndex testindex = type_box_->view()->selectionModel()->currentIndex();
         if (testindex.row() != -1) {
             type_box_->setCurrentIndex(testindex.row());
         }
@@ -378,8 +378,8 @@ void NewPartitionFrame::changeEvent(QEvent* event) {
     size_label_->setText(::QObject::tr("Size"));
     alignment_box_->clear();
     alignment_box_->addItems({::QObject::tr("Start"), ::QObject::tr("End")});
-    cancel_button_->setText(::QObject::tr("Cancel"));
-    create_button_->setText(::QObject::tr("Create"));
+    cancel_button_->setText(::QObject::tr("Cancel", "button"));
+    create_button_->setText(::QObject::tr("Create", "button"));
 
     if (m_close_button) {
         m_close_button->move(width() - m_close_button->width(), 0);
@@ -543,16 +543,18 @@ void NewPartitionFrame::initUI() {
 
   int topMargin = ScreenAdaptationManager::instance()->getChildWindowTopMargin();
   layout->setContentsMargins(0, topMargin, 0, 0);
+  layout->setSpacing(0);
+
   layout->addSpacing(0);
   layout->addWidget(title_label_, 0, Qt::AlignCenter | Qt::AlignTop);
-  layout->addSpacing(kMainLayoutSpacing);
+  layout->addSpacing(10);
 
   layout->addWidget(content_frame, 0, Qt::AlignHCenter | Qt::AlignTop);
   layout->addStretch();
   layout->addWidget(m_auto_label, 0, Qt::AlignHCenter | Qt::AlignBottom);
-  layout->addSpacing(8);
+  layout->addSpacing(5);
   layout->addLayout(bt_layout);
-  layout->addSpacing(20);
+  layout->addSpacing(10);
 
   this->setLayout(layout);
   this->setContentsMargins(0, 0, 0, 0);
@@ -717,10 +719,12 @@ void NewPartitionFrame::onCreateButtonClicked() {
       }
 
       if (align_start) {//从起点开始创建
-          //创建EFI分区
-          if (table == PartitionTableType::GPT && device->device_type == DeviceType::NormalDevice) {
-              delegate_->createPartition(partition_, partition_type, align_start, FsType::EFI,
-                                         "", total_sectors_auto);
+          if (GetCurrentPlatform() != "sw") {
+              //创建EFI分区
+              if (table == PartitionTableType::GPT && device->device_type == DeviceType::NormalDevice) {
+                  delegate_->createPartition(partition_, partition_type, align_start, FsType::EFI,
+                                             "", total_sectors_auto, QString(), false, false);
+              }
           }
 
           //创建/分区
@@ -754,19 +758,21 @@ void NewPartitionFrame::onCreateButtonClicked() {
           total_sectors_auto = rootSapce / partition_->sector_size;
           delegate_->createPartition(partition_, partition_type, align_start, fs_type,
                                      kMountPointRoot, total_sectors_auto);
-          //创建EFI
-          if (table == PartitionTableType::GPT && device->device_type == DeviceType::NormalDevice) {
-              partition_ = device->partitions.at(indexPartition);
-              total_sectors_auto = efi_recommended * kMebiByte / partition_->sector_size;
-              delegate_->createPartition(partition_, partition_type, align_start, FsType::EFI,
-                                         "", total_sectors_auto);
-          }
 
+          if (GetCurrentPlatform() != "sw") {
+              //创建EFI
+              if (table == PartitionTableType::GPT && device->device_type == DeviceType::NormalDevice) {
+                  partition_ = device->partitions.at(indexPartition);
+                  total_sectors_auto = efi_recommended * kMebiByte / partition_->sector_size;
+                  delegate_->createPartition(partition_, partition_type, align_start, FsType::EFI,
+                                             "", total_sectors_auto);
+              }
+          }
       }
 
   } else {
       delegate_->createPartition(partition_, partition_type, align_start, fs_type,
-                                 mount_point, total_sectors);      
+                                 mount_point, total_sectors, QString(), false, false);
   }
 
   delegate_->refreshVisual();
