@@ -16,10 +16,6 @@ class QScrollArea;
 class QAbstractButton;
 
 namespace installer {
-namespace {
-    const int kChineseToggleButtonId = 0;
-    const int kEnglishToggleButtonId = 1;
-}
 
 class UserAgreementFrame : public QFrame
 {
@@ -27,8 +23,6 @@ class UserAgreementFrame : public QFrame
 public:
     explicit UserAgreementFrame(QWidget *parent = nullptr);
     void setUserAgreement(const QString &primaryFileName, const QString &secondaryFileName = QString(""));
-    void setCheckedButton(int buttonId);
-    void setTitle(const QString &text);
 
     bool focusSwitch();
     bool doSelect();
@@ -46,24 +40,16 @@ private:
     void initUI();
     void initConnect();
     void updateText();
-    void toggleLicense(QAbstractButton* button);
     void updateLicenseText();
 
 private:
     QLabel *m_logoLbl;
-    QLabel *m_subTitle;
-    DButtonBoxButton* m_chineseButton = nullptr;
-    DButtonBoxButton* m_englishButton = nullptr;
-    QAbstractButton* m_currentButton = nullptr;
-    DButtonBox* m_buttonBox = nullptr;
-    QWidget* m_buttonBoxWidget = nullptr;
     QLabel *m_sourceLbl;
     QPushButton *m_back;
     QScrollArea *m_sourceScrollArea;
     QLocale::Language m_language;
     int m_nextFileIndex;
     QStringList m_fileNames;
-    QList<DButtonBoxButton *> m_btnlist;
 };
 }
 #endif // INSTALLER_UI_FRAMES_USER_AGREEMENT_FRAME_H
